Crate librpmbuild_sys

Crate librpmbuild_sys 

rpmbuild library (i.e. librpmbuild.so) FFI bindings.

Automatically generated by bindgen.

This crate isn’t intended to be used directly, but instead provides the low-level binding which is used by the idiomatic librpm crate.